@@ -5,6 +5,10 @@
 #include "gdtest.h"
 #include <jpeglib.h>
 
+#ifdef _MSC_VER
+# define snprintf _snprintf
+#endif
+
 int main()
 {
 #if defined(JPEG_LIB_VERSION_MAJOR) && JPEG_LIB_VERSION_MAJOR >= 8
@@ -12,8 +16,16 @@ int main()
 	return 0;
 #else
 	gdImagePtr im;
-	int error = 0;
-	FILE *fp = gdTestFileOpen("jpeg/conv_test.jpeg");
+	FILE *fp;
+	char path[1024];
+
+	snprintf(path, sizeof(path)-1, "%s/jpeg/conv_test.jpeg", GDTEST_TOP_DIR);
+	fp = fopen(path, "rb");
+	if (!fp) {
+		gdTestErrorMsg("failed, cannot open file: %s\n", path);
+		return 1;
+	}
+
 	im = gdImageCreateFromJpeg(fp);
 	fclose(fp);
 
@@ -21,10 +33,14 @@ int main()
 		gdTestErrorMsg("gdImageCreateFromJpeg failed.\n");
 		return 1;
 	}
-	if (!gdAssertImageEqualsToFile("jpeg/conv_test_exp.png", im))
-		error = 1;
+	snprintf(path, sizeof(path), "%s/jpeg/conv_test_exp.png", GDTEST_TOP_DIR);
+	if (!gdAssertImageEqualsToFile(path, im)) {
+		gdTestErrorMsg("gdAssertImageEqualsToFile failed: <%s>.\n", path);
+		gdImageDestroy(im);
+		return 1;
+	}
 
 	gdImageDestroy(im);
-	return error;
+	return 0;
 #endif
 }
